@@ -4,7 +4,7 @@ from aj.plugins.core.api.sidebar import SidebarItemProvider
 
 
 @component(SidebarItemProvider)
-class ItemProvider(SidebarItemProvider):
+class ItemProvider (SidebarItemProvider):
     def __init__(self, context):
         pass
 
@@ -12,7 +12,7 @@ class ItemProvider(SidebarItemProvider):
         return [
             {
                 'attach': 'category:general',
-                'name': 'Dashboard',
+                'name': _('Dashboard'),
                 'icon': 'bar-chart',
                 'url': '/view/dashboard',
                 'children': [
